""" Manipulate durations

This module enable to manipulate durations. It mostly supetimedelta
"""

from datetime import timedelta


class Duration(timedelta):

    @classmethod
    def from_str(cls, duration: str) -> timedelta:
        """ return a duration from a string

        Format of the string can be either hh:mm:ss, mm:ss or mm.

        Examples
        ========
        >>> Duration.from_str('1:22:23')
        datetime.timedelta(seconds=4943)
        >>> Duration.from_str('3:10')
        datetime.timedelta('190')
        >>> Duration.from_str('3')
        datetime.timedelta('180')
        """
        d = [int(t) for t in duration.split(':')]
        hours, minutes, seconds = 0, 0, 0
        if len(d) == 1:
            minutes = int(d[0])
        elif len(d) == 2:
            minutes, seconds = int(d[0]), int(d[1])
        elif len(d) == 3:
            hours, minutes, seconds = int(d[0]), int(d[1]), int(d[2])
        else:
            raise ValueError('Error in the given duration')
        return cls(hours=hours, minutes=minutes, seconds=seconds)
